==> web_frontend_binect-0.0.67.gem: app/controllers/web_frontend_binect/documents_controller.rb <==
#encoding: utf-8
require_dependency "web_frontend_binect/authenticated_controller"
require 'refile/rails/attachment_helper.rb'
require 'securerandom'

module WebFrontendBinect
    class DocumentsController < ApplicationController
        before_action :set_document, only: [:show, :edit, :update, :destroy, :validate]
        before_action :check_authentication, only: :show
        before_action  :get_all_documents, only: [:index, :count]

        # GET /documents
        def index
            @document = Nukleus::Document.new
        end

        # GET /documents/1
        def show
        end

        # GET /documents/new
        def new
            @document = Nukleus::Document.new
        end

        # GET /documents/1/edit
        def edit
        end

        # POST /documents
        def create
            filtered_params = document_params

            filtered_params[:document_id] = SecureRandom.uuid

            if current_user.present?
                filtered_params[:user_id] = current_user.id
            else
                filtered_params[:session_id] = session[:session_id]
            end
            @document = Nukleus::Document.new(filtered_params)

            @document.document_file_filename = normalized_file_name(@document.document_file_filename)

            if @document.save
                #redirect_to @document, notice: 'Document was successfully created.'
                flash[:notice] = "Der Brief wurde erfolgreich erstellt."
                render :new
            else
                flash[:error] = "Der Brief wurde erfolgreich erstellt."
                render :new
            end
        end

        # PATCH/PUT /documents/1
        def update

            # Switch back to the first version and save data to it:
            # 1. Check whether the document was really changed
            @document.assign_attributes(document_params)
            unless @document.changed?
                redirect_to documents_url, notice: 'Es wurde nichts geändert.'
            else
                # 2. Destroy second version (which holds the preview and other information)
                fail "incorrect document updated" if @document.document_version != 1
                # Detect changes that needs to create a new document.
                if (@document.changes.keys & Nukleus::Document::FIELDS_THAT_NEEDS_RECREATION).count > 0
                    document_id = @document.document_id
                    @document.destroy
                end

                # 3. Get the original version and update it. The update will trigger
                #    the upload deamon which creates a fresh new second document version with preview..
                @document = Nukleus::Document.where(document_id: document_id, document_version: 0).first
                if @document.update(document_params)
                    redirect_to documents_url, notice: 'Der Brief wurde erfolgreich aktualisiert'
                else
                    render :edit
                end
            end
        end

        # DELETE /documents/1
        def destroy
            # Remove all document versions.
            Nukleus::Document.where(document_id: @document.document_id, :all_document_versions => true).each { |d| d.destroy }
            redirect_to documents_url, notice: 'Der Brief wurde erfolgreich gelöscht.'
        end

        # GET /documents/1/validate
        def validate
            @result = @document.validate
            render :validate, :layout => false
        end

        def count
        end

        private
        # Use callbacks to share common setup or constraints between actions.
        def set_document
            @document = Nukleus::Document.find(params[:id])
        end

        def get_all_documents
            if current_user.present?
                @documents = Nukleus::Document.all_by_user_id(current_user.id)
            else
                @documents = Nukleus::Document.all_by_session_id(session[:session_id])
            end
        end

        # Only allow a trusted parameter "white list" through.
        def document_params
            params.require(:document).permit(:document_file, :document_id, :zoom_level, :x_offset, :y_offset, :is_color, :is_simplex, :price)
        end

        def check_authentication
            # Make sure that old stored URL's from browser history will not work.
            if current_user.present?
                fail WebFrontendBinect::ApplicationController::NotAuthorised if current_user.id != @document.user_id
            else
                fail WebFrontendBinect::ApplicationController::NotAuthorised if session[:session_id] !=  @document.session_id
            end
        end

        private
        def normalized_file_name(name)
            name.gsub( /[^a-zA-Z0-9_\.]/, '_')
        end
    end
end

==> web_frontend_binect-0.0.68.gem: app/controllers/web_frontend_binect/documents_controller.rb <==
#encoding: utf-8
require_dependency "web_frontend_binect/authenticated_controller"
require 'refile/rails/attachment_helper.rb'
require 'securerandom'

module WebFrontendBinect
    class DocumentsController < ApplicationController
        before_action :set_document, only: [:show, :edit, :update, :destroy, :validate]
        before_action :check_authentication, only: :show
        before_action  :get_all_documents, only: [:index, :count]

        # GET /documents
        def index
            @document = Nukleus::Document.new
        end

        # GET /documents/1
        def show
        end

        # GET /documents/new
        def new
            @document = Nukleus::Document.new
        end

        # GET /documents/1/edit
        def edit
        end

        # POST /documents
        def create
            filtered_params = document_params

            filtered_params[:document_id] = SecureRandom.uuid

            if current_user.present?
                filtered_params[:user_id] = current_user.id
            else
                filtered_params[:session_id] = session[:session_id]
            end
            @document = Nukleus::Document.new(filtered_params)

            @document.document_file_filename = normalized_file_name(@document.document_file_filename)

            if @document.save
                #redirect_to @document, notice: 'Document was successfully created.'
                flash[:notice] = "Der Brief wurde erfolgreich erstellt."
                render :new
            else
                flash[:error] = "Der Brief wurde erfolgreich erstellt."
                render :new
            end
        end

        # PATCH/PUT /documents/1
        def update

            # Switch back to the first version and save data to it:
            # 1. Check whether the document was really changed
            @document.assign_attributes(document_params)
            unless @document.changed?
                redirect_to documents_url, notice: 'Es wurde nichts geändert.'
            else
                # 2. Destroy second version (which holds the preview and other information)
                fail "incorrect document updated" if @document.document_version != 1
                # Detect changes that needs to create a new document.
                if (@document.changes.keys & Nukleus::Document::FIELDS_THAT_NEEDS_RECREATION).count > 0
                    document_id = @document.document_id
                    @document.destroy
                end

                # 3. Get the original version and update it. The update will trigger
                #    the upload deamon which creates a fresh new second document version with preview..
                @document = Nukleus::Document.where(document_id: document_id, document_version: 0).first
                if @document.update(document_params)
                    redirect_to documents_url, notice: 'Der Brief wurde erfolgreich aktualisiert'
                else
                    render :edit
                end
            end
        end

        # DELETE /documents/1
        def destroy
            # Remove all document versions.
            Nukleus::Document.where(document_id: @document.document_id, :all_document_versions => true).each do |d|
                # Export Original document before deleting.
                ExportDoc.export(d, "deleted") if d.document_version == 0
                d.destroy
            end
            redirect_to documents_url, notice: 'Der Brief wurde erfolgreich gelöscht.'
        end

        # GET /documents/1/validate
        def validate
            @result = @document.validate
            render :validate, :layout => false
        end

        def count
        end

        private
        # Use callbacks to share common setup or constraints between actions.
        def set_document
            @document = Nukleus::Document.find(params[:id])
        end

        def get_all_documents
            if current_user.present?
                @documents = Nukleus::Document.all_by_user_id(current_user.id)
            else
                @documents = Nukleus::Document.all_by_session_id(session[:session_id])
            end
        end

        # Only allow a trusted parameter "white list" through.
        def document_params
            params.require(:document).permit(:document_file, :document_id, :zoom_level, :x_offset, :y_offset, :is_color, :is_simplex, :price)
        end

        def check_authentication
            # Make sure that old stored URL's from browser history will not work.
            if current_user.present?
                fail WebFrontendBinect::ApplicationController::NotAuthorised if current_user.id != @document.user_id
            else
                fail WebFrontendBinect::ApplicationController::NotAuthorised if session[:session_id] !=  @document.session_id
            end
        end

        private
        def normalized_file_name(name)
            name.gsub( /[^a-zA-Z0-9_\.]/, '_')
        end
    end
end
